@@ -1,4 +1,4 @@
-from behance import Behance
+from behance_python.behance import Behance
 from behance_python import ENDPOINTS, url_join
 
 class Project(Behance):
